# Environ
Environ is a **python** framework built for you to manage your project in a few clicks, it creates an integrated file environment so your project can be awesome, a shell called EnvironShell which you can use to manage your project ALL IN ONE!


How to access environshell:
` python -m environ shell `


A few EnvironShell commands:
` help `,
` crfile [FILENAME] [CONTENTS] `
"Contents can contain \n to declare newlines"

LAST_CHANGELOG:
* Fixed Dependecy Version Error
* Added License
* Added EnvironShell access point
* Fixed Fetching version


SHORT CHANGELOG **(0.0.3)**:
* fixed error for base package running; Error: **Traceback (most recent call last):**
  **File "C:\Program Files\WindowsApps\PythonSoftwareFoundation.Python.3.10_3.10.2544.0_x64__qbz5n2kfra8p0\lib\runpy.py", line 187, in** **_run_module_as_main**
    **mod_name, mod_spec, code = _get_module_details(mod_name, _Error)**
  **File "C:\Program Files\WindowsApps\PythonSoftwareFoundation.Python.3.10_3.10.2544.0_x64__qbz5n2kfra8p0\lib\runpy.py", line 146, in** **_get_module_details**
    **return _get_module_details(pkg_main_name, error)**
  **File "C:\Program Files\WindowsApps\PythonSoftwareFoundation.Python.3.10_3.10.2544.0_x64__qbz5n2kfra8p0\lib\runpy.py", line 110, in** **_get_module_details**
  **__import__(pkg_name)**
  **File "C:\Users\Rayaans Laptop\AppData\Local\Packages\PythonSoftwareFoundation.Python.3.****10_qbz5n2kfra8p0\LocalCache\local-packages\Python310\site-packages\environpy\__init__.py", line 2, in <module>**
    **from dev import create_dependencies**
**ModuleNotFoundError: No module named 'dev'**

*DISCLAIMER: SOME SYNTAX IN ERROR TRACEBACK DISRUPTED DUE TO MARKDOWN*
